@@ -60,7 +60,7 @@ class Freebox(IPlugin):
 					resp = requests.get ('http://hd2.freebox.fr/pub/remote_control?code=%s&key=%s' % (code_Fb,rs['idx'])
 #					log.msg("resp  :  %s" % (req))				
 #					resp = requests.get (req)
-					log.msg("resp  :  %s" % (resp))
+#					log.msg("resp  :  %s" % (resp))
 		if bodies == "":
 			bodies = "j'ai rien compris aux switch"
 		return {"plugin": "Freebox",
